==> libbpp-phyl_2.0.3.orig.tar.gz: bpp-phyl-2.0.3/src/Bpp/Phyl/Mapping/ProbabilisticSubstitutionMapping.cpp <==
//
// File: ProbabilisticSubstitutionMapping.cpp
// Created by: Julien Dutheil
// Created on: Wed Apr 5 10:47 2006
//

/*
Copyright or © or Copr. Bio++ Development Team, (November 16, 2004, 2005, 2006)

This software is a computer program whose purpose is to provide classes
for phylogenetic data analysis.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/

#include "ProbabilisticSubstitutionMapping.h"

using namespace bpp;

void ProbabilisticSubstitutionMapping::setTree(const Tree& tree)
{
  AbstractSubstitutionMapping::setTree(tree);
  for (unsigned int i = 0; i < getNumberOfSites(); i++) {
    mapping_[i].resize(getNumberOfBranches());
    for (unsigned int j = 0; j < getNumberOfBranches(); j++) {
      mapping_[i][j].resize(1);
    }
  }
}

void ProbabilisticSubstitutionMapping::setNumberOfSites(unsigned int numberOfSites)
{
  AbstractSubstitutionMapping::setNumberOfSites(numberOfSites);
  mapping_.resize(numberOfSites);
  for (unsigned int i = 0; i < numberOfSites; i++) {
    mapping_[i].resize(getNumberOfBranches());
    for (unsigned int j = 0; j < getNumberOfBranches(); j++) {
      mapping_[i][j].resize(getNumberOfSubstitutionTypes());
    }
  }
}

==> libbpp-phyl_2.4.1.orig.tar.gz: bpp-phyl-2.4.1/src/Bpp/Phyl/Mapping/ProbabilisticSubstitutionMapping.cpp <==
//
// File: ProbabilisticSubstitutionMapping.cpp
// Created by: Julien Dutheil
// Created on: Wed Apr 5 10:47 2006
//

/*
Copyright or © or Copr. Bio++ Development Team, (November 16, 2004, 2005, 2006)

This software is a computer program whose purpose is to provide classes
for phylogenetic data analysis.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/

#include "ProbabilisticSubstitutionMapping.h"

using namespace bpp;

void ProbabilisticSubstitutionMapping::setTree(const Tree& tree)
{
  AbstractSubstitutionMapping::setTree(tree);
  for (size_t i = 0; i < getNumberOfSites(); i++) {
    mapping_[i].resize(getNumberOfBranches());
    for (size_t j = 0; j < getNumberOfBranches(); j++) {
      mapping_[i][j].resize(1);
    }
  }
}

void ProbabilisticSubstitutionMapping::setNumberOfSites(size_t numberOfSites)
{
  AbstractSubstitutionMapping::setNumberOfSites(numberOfSites);
  mapping_.resize(numberOfSites);
  for (size_t i = 0; i < numberOfSites; i++) {
    mapping_[i].resize(getNumberOfBranches());
    for (size_t j = 0; j < getNumberOfBranches(); j++) {
      mapping_[i][j].resize(getNumberOfSubstitutionTypes());
    }
  }
}
